traceplot: Traceplots for MCMC samples

View source: R/amerasfunctions.R

traceplotR Documentation

Traceplots for MCMC samples

Description

Produce MCMC traceplots for amerasfit objects.

Usage

traceplot(object, ...)

## S3 method for class 'amerasfit'
traceplot(object, iter = 5000, Rhat = TRUE, n.eff = TRUE, pdf = FALSE, ...)

Arguments

object

a amerasfit object containing BMA output to be plotted

iter

number of iterations to include in the traceplot (defaults to last 5000)

Rhat

logical; whether to include R-hat diagnostics in the plot (default TRUE)

n.eff

logical; whether to include effective sample size in the plot (default TRUE)

pdf

logical; whether to save the output as a PDF (default FALSE)

...

additional arguments passed to MCMCtrace

Details

Wrapper for MCMCvis::MCMCtrace to produce MCMC diagnostic plots. See ?MCMCtrace for more plotting options that can be provided through ....

Value

Traceplots and posterior density plots.

See Also

MCMCtrace

Examples


   data(data, package="ameras")
   fit <- ameras(data, methods="BMA", Y="Y.gaussian", dosevars=paste0("V", 1:10))
   traceplot(fit)


ameras documentation built on March 29, 2026, 5:07 p.m.