transform1jacobian: Jacobian of the exponential parameter transformation

transform1.jacobianR Documentation

Jacobian of the exponential parameter transformation

Description

Computes the Jacobian matrix of transform1. Note that lower limits do not need to be specified as the Jacobian is independent of those

Usage

transform1.jacobian(params, index.t=1:length(params), ... )

Arguments

params

input parameter vector (before transformation) to evaluate the Jacobian at

index.t

indices of parameters to be transformed (default all)

...

not used

Value

Jacobian matrix.

Examples

params <- c(.1, .5, 1)
transform1.jacobian(params)

ameras documentation built on March 29, 2026, 5:07 p.m.