data: Example data

dataR Documentation

Example data

Description

Data includes outcomes of all six supported types in the appropriately named columns. For proportional hazards regression, the observed exit time is time and event status is event. For conditional logistic regression, the matched set variable is setnr. The data has 10 exposure replicates in columns V1-V10.

Examples


 data(data, package="ameras")

 # Display a few rows of the data
 data[1:5, ]


ameras documentation built on March 29, 2026, 5:07 p.m.