View source: R/amerasfunctions.R
| traceplot | R Documentation |
Produce MCMC traceplots for amerasfit objects.
traceplot(object, ...)
## S3 method for class 'amerasfit'
traceplot(object, iter = 5000, Rhat = TRUE, n.eff = TRUE, pdf = FALSE, ...)
object |
a |
iter |
number of iterations to include in the traceplot (defaults to last 5000) |
Rhat |
logical; whether to include R-hat diagnostics in the plot (default TRUE) |
n.eff |
logical; whether to include effective sample size in the plot (default TRUE) |
pdf |
logical; whether to save the output as a PDF (default FALSE) |
... |
additional arguments passed to |
Wrapper for MCMCvis::MCMCtrace to produce MCMC diagnostic plots. See ?MCMCtrace for more plotting options that can be provided through ....
Traceplots and posterior density plots.
MCMCtrace
data(data, package="ameras")
fit <- ameras(data, methods="BMA", Y="Y.gaussian", dosevars=paste0("V", 1:10))
traceplot(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.