| transform1.jacobian | R Documentation |
Computes the Jacobian matrix of transform1. Note that lower limits do not need to be specified as the Jacobian is independent of those
transform1.jacobian(params, index.t=1:length(params), ... )
params |
input parameter vector (before transformation) to evaluate the Jacobian at |
index.t |
indices of parameters to be transformed (default all) |
... |
not used |
Jacobian matrix.
params <- c(.1, .5, 1)
transform1.jacobian(params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.